@@ -52,7 +52,7 @@ public class LzFixedTextField  extends JTextField {
 		return new LzFixedTextDocument();
 	}
 
-	private class LzFixedTextDocument extends PlainDocument {
+	class LzFixedTextDocument extends PlainDocument {
 		public void insertString(int offs, String str, AttributeSet a) throws BadLocationException {
 			if (str == null) {
 				return;
